@@ -7,7 +7,7 @@ use ratatui::widgets::Clear;
 use termion::event::Event;
 
 use crate::config::raw::bookmarks::{BookmarkRaw, BookmarksRaw};
-use crate::config::search_directories;
+use crate::config::{search_directories, ConfigType};
 use crate::context::AppContext;
 use crate::error::AppResult;
 use crate::event::{process_event, AppEvent};
@@ -17,7 +17,7 @@ use crate::ui::widgets::TuiMenu;
 use crate::ui::AppBackend;
 use crate::util::unix;
 
-use crate::{BOOKMARKS_FILE, BOOKMARKS_T, CONFIG_HIERARCHY};
+use crate::{BOOKMARKS_T, CONFIG_HIERARCHY};
 
 use super::change_directory::change_directory;
 
@@ -33,10 +33,11 @@ fn find_bookmark_file() -> Option<path::PathBuf> {
 pub fn add_bookmark(context: &mut AppContext, backend: &mut AppBackend) -> AppResult {
     let cwd = std::env::current_dir()?;
 
-    let bookmark_path = match search_directories(BOOKMARKS_FILE, &CONFIG_HIERARCHY) {
-        Some(file_path) => Some(file_path),
-        None => find_bookmark_file(),
-    };
+    let bookmark_path =
+        match search_directories(ConfigType::Bookmarks.as_filename(), &CONFIG_HIERARCHY) {
+            Some(file_path) => Some(file_path),
+            None => find_bookmark_file(),
+        };
 
     if let Some(bookmark_path) = bookmark_path {
         let key = poll_for_bookmark_key(context, backend);
@@ -108,19 +109,20 @@ fn poll_for_bookmark_key(context: &mut AppContext, backend: &mut AppBackend) ->
                 frame.render_widget(view, area);
             }
 
-            let menu_widget = TuiMenu::new(bookmarks_str.as_slice());
-            let menu_len = menu_widget.len();
-            let menu_y = if menu_len + 1 > area.height as usize {
-                0
+            let (menu_widget, menu_y) = if bookmarks_str.len() > area.height as usize - 1 {
+                (TuiMenu::new(&bookmarks_str[0..area.height as usize - 1]), 0)
             } else {
-                (area.height as usize - menu_len - 1) as u16
+                (
+                    TuiMenu::new(bookmarks_str.as_slice()),
+                    (area.height as usize - bookmarks_str.len() - 1) as u16,
+                )
             };
 
             let menu_rect = Rect {
                 x: 0,
-                y: menu_y - 1,
+                y: menu_y,
                 width: area.width,
-                height: menu_len as u16 + 1,
+                height: menu_widget.len() as u16 + 1,
             };
             frame.render_widget(Clear, menu_rect);
             frame.render_widget(menu_widget, menu_rect);
