@@ -3,7 +3,7 @@ use std::path;
 use crate::commands::reload;
 use crate::context::AppContext;
 use crate::error::AppResult;
-use crate::history::DirectoryHistory;
+use crate::history::{generate_entries_to_root, DirectoryHistory};
 use crate::util::cwd;
 
 // ChangeDirectory command
@@ -28,18 +28,18 @@ pub fn change_directory(context: &mut AppContext, mut path: &path::Path) -> AppR
     };
 
     cd(new_cwd.as_path(), context)?;
-    let options = context.config_ref().display_options_ref().clone();
-    let ui_context = context.ui_context_ref().clone();
-    let tab_options = context
-        .tab_context_ref()
-        .curr_tab_ref()
-        .option_ref()
-        .clone();
+    let dirlists = generate_entries_to_root(
+        new_cwd.as_path(),
+        context.tab_context_ref().curr_tab_ref().history_ref(),
+        context.ui_context_ref(),
+        context.config_ref().display_options_ref(),
+        context.tab_context_ref().curr_tab_ref().option_ref(),
+    )?;
     context
         .tab_context_mut()
         .curr_tab_mut()
         .history_mut()
-        .populate_to_root(new_cwd.as_path(), &ui_context, &options, &tab_options)?;
+        .insert_entries(dirlists);
     Ok(())
 }
 
