@@ -1,9 +1,9 @@
 use crate::context::AppContext;
-use crate::error::JoshutoResult;
+use crate::error::AppResult;
 
 use super::reload;
 
-pub fn flatten(context: &mut AppContext, depth: usize) -> JoshutoResult {
+pub fn flatten(context: &mut AppContext, depth: usize) -> AppResult {
     let curr_tab = context.tab_context_mut().curr_tab_mut();
     let path = curr_tab.cwd().to_path_buf();
     curr_tab
