@@ -1,6 +1,7 @@
 mod app_context;
 mod commandline_context;
 mod local_state;
+mod matcher;
 mod message_queue;
 mod preview_context;
 mod tab_context;
@@ -10,6 +11,7 @@ mod worker_context;
 pub use self::app_context::*;
 pub use self::commandline_context::*;
 pub use self::local_state::*;
+pub use self::matcher::*;
 pub use self::message_queue::*;
 pub use self::preview_context::*;
 pub use self::tab_context::*;
