@@ -69,8 +69,10 @@ cmd_constants![
     (CMD_SET_MODE, "set_mode"),
     (CMD_SORT, "sort"),
     (CMD_SORT_REVERSE, "sort reverse"),
-    (CMD_SUBPROCESS_FOREGROUND, "shell"),
-    (CMD_SUBPROCESS_BACKGROUND, "spawn"),
+    (CMD_SUBPROCESS_INTERACTIVE, "shell"),
+    (CMD_SUBPROCESS_SPAWN, "spawn"),
+    (CMD_SUBPROCESS_CAPTURE, "capture"),
+    (CMD_STDOUT_POST_PROCESS, "stdout"),
     (CMD_SHOW_TASKS, "show_tasks"),
     (CMD_TAB_SWITCH, "tab_switch"),
     (CMD_TAB_SWITCH_INDEX, "tab_switch_index"),
