@@ -4,8 +4,9 @@ use ratatui::style::{Color, Style};
 use ratatui::symbols::line::{HORIZONTAL_DOWN, HORIZONTAL_UP};
 use ratatui::text::Span;
 use ratatui::widgets::{Block, Borders, Paragraph, Widget, Wrap};
+use ratatui_image::Image;
 
-use crate::context::AppContext;
+use crate::context::{AppContext, PreviewContext, TabContext};
 use crate::preview::preview_dir::PreviewDirState;
 use crate::preview::preview_file::PreviewFileState;
 use crate::ui;
@@ -142,14 +143,14 @@ impl<'a> Widget for TuiFolderView<'a> {
             Constraint::Ratio(0, _) => {}
             _ => {
                 if let Some(list) = curr_tab.parent_list_ref().as_ref() {
-                    TuiDirList::new(list, true).render(layout_rect[0], buf);
+                    TuiDirList::new(config, list, true).render(layout_rect[0], buf);
                 }
             }
         }
 
         // render current view
         if let Some(list) = curr_list.as_ref() {
-            TuiDirListDetailed::new(list, display_options, curr_tab.option_ref(), true)
+            TuiDirListDetailed::new(config, list, display_options, curr_tab.option_ref(), true)
                 .render(layout_rect[1], buf);
 
             let footer_area = Self::footer_area(&area);
@@ -184,7 +185,7 @@ impl<'a> Widget for TuiFolderView<'a> {
         }
 
         if let Some(list) = child_list.as_ref() {
-            TuiDirList::new(list, true).render(layout_rect[2], buf);
+            TuiDirList::new(config, list, true).render(layout_rect[2], buf);
         } else if let Some(entry) = curr_entry {
             match curr_tab.history_metadata_ref().get(entry.file_path()) {
                 Some(PreviewDirState::Loading) => {
@@ -195,21 +196,36 @@ impl<'a> Widget for TuiFolderView<'a> {
                         .render(layout_rect[2], buf);
                 }
                 None => {
-                    let preview_area = calculate_preview(self.context, layout_rect[2]);
-                    if let Some(preview_area) = preview_area {
-                        let area = Rect {
-                            x: preview_area.preview_area.x,
-                            y: preview_area.preview_area.y,
-                            width: preview_area.preview_area.width,
-                            height: preview_area.preview_area.height,
-                        };
-                        if let Some(PreviewFileState::Success { data }) = preview_context
-                            .previews_ref()
-                            .get(&preview_area.file_preview_path)
-                        {
+                    let image_offset = match preview_context.image_preview_ref(entry.file_path()) {
+                        Some(protocol) => {
+                            let area = layout_rect[2];
+                            Image::new(protocol).render(area, buf);
+                            protocol.rect().height
+                        }
+                        _ => 0,
+                    };
+
+                    if let Some(PreviewFileState::Success(data)) =
+                        preview_context.previews_ref().get(entry.file_path())
+                    {
+                        let preview_area = calculate_preview(
+                            self.context.tab_context_ref(),
+                            self.context.preview_context_ref(),
+                            layout_rect[2],
+                        );
+                        if let Some(preview_area) = preview_area {
+                            let area = Rect {
+                                x: preview_area.preview_area.x,
+                                y: preview_area.preview_area.y + image_offset,
+                                width: preview_area.preview_area.width,
+                                height: preview_area
+                                    .preview_area
+                                    .height
+                                    .saturating_sub(image_offset),
+                            };
                             TuiFilePreview::new(data).render(area, buf);
                         }
-                    }
+                    };
                 }
             }
         } else {
@@ -268,11 +284,8 @@ pub fn get_constraints(context: &AppContext) -> &[Constraint; 3] {
                     &display_options.default_layout
                 }
                 Some(entry) => match preview_context.previews_ref().get(entry.file_path()) {
-                    Some(PreviewFileState::Success { data }) if data.status.code() != Some(1) => {
-                        &display_options.default_layout
-                    }
-                    Some(PreviewFileState::Loading) => &display_options.default_layout,
-                    _ => &display_options.no_preview_layout,
+                    None => &display_options.no_preview_layout,
+                    _ => &display_options.default_layout,
                 },
             },
         }
@@ -315,9 +328,12 @@ pub fn calculate_layout_with_borders(area: Rect, constraints: &[Constraint; 3])
     vec![inner1, layout_rect[1], inner3]
 }
 
-pub fn calculate_preview(context: &AppContext, rect: Rect) -> Option<PreviewArea> {
-    let preview_context = context.preview_context_ref();
-    let curr_tab = context.tab_context_ref().curr_tab_ref();
+pub fn calculate_preview(
+    tab_context: &TabContext,
+    preview_context: &PreviewContext,
+    rect: Rect,
+) -> Option<PreviewArea> {
+    let curr_tab = tab_context.curr_tab_ref();
 
     let child_list = curr_tab.child_list_ref();
 
@@ -327,24 +343,18 @@ pub fn calculate_preview(context: &AppContext, rect: Rect) -> Option<PreviewArea
     if child_list.as_ref().is_some() {
         None
     } else if let Some(entry) = curr_entry {
-        if let Some(PreviewFileState::Success { data }) =
-            preview_context.previews_ref().get(entry.file_path())
-        {
-            match data.status.code() {
-                Some(1) | None => None,
-                _ => {
-                    let file_preview_path = entry.file_path_buf();
-                    let preview_area = ui::Rect {
-                        x: rect.x,
-                        y: rect.y,
-                        width: rect.width,
-                        height: rect.height,
-                    };
-                    Some(PreviewArea::new(file_preview_path, preview_area))
-                }
+        match preview_context.previews_ref().get(entry.file_path()) {
+            None | Some(PreviewFileState::Loading) | Some(PreviewFileState::Error(_)) => None,
+            _ => {
+                let file_preview_path = entry.file_path_buf();
+                let preview_area = ui::Rect {
+                    x: rect.x,
+                    y: rect.y,
+                    width: rect.width,
+                    height: rect.height,
+                };
+                Some(PreviewArea::new(file_preview_path, preview_area))
             }
-        } else {
-            None
         }
     } else {
         None
