@@ -7,7 +7,6 @@ mod tui_help;
 mod tui_menu;
 mod tui_message;
 mod tui_prompt;
-mod tui_tab;
 mod tui_text;
 mod tui_topbar;
 mod tui_worker;
@@ -21,7 +20,6 @@ pub use self::tui_help::{get_keymap_table, TuiHelp};
 pub use self::tui_menu::TuiMenu;
 pub use self::tui_message::TuiMessage;
 pub use self::tui_prompt::TuiPrompt;
-pub use self::tui_tab::TuiTabBar;
 pub use self::tui_text::TuiMultilineText;
 pub use self::tui_topbar::TuiTopBar;
 pub use self::tui_worker::TuiWorker;
